@@ -1,4 +1,4 @@
-library("testthat")
+library("testthat", warn.conflicts = FALSE)
 library("TreeDist")
 
 test_check("TreeDist")
